@@ -39,7 +39,9 @@ var commandRules = []linter.CommandRule{
 	linter.RequireValidExamples(),
 
 	// Soft Requirements
-	linter.RequireLengthBetween("Short", 10, 60),
+	linter.Filter(linter.RequireLengthBetween("Short", 10, 60),
+		linter.ExcludeCommand("audit-log config edit"),
+		linter.ExcludeCommand("audit-log config update")),
 }
 
 var flagRules = []linter.FlagRule{
@@ -139,6 +141,7 @@ var flagRules = []linter.FlagRule{
 			"source-api-secret",
 			"source-bootstrap-server",
 			"update-schema-registry",
+			"use-schema-registry",
 		),
 	),
 }
@@ -263,6 +266,9 @@ var vocabWords = []string{
 	"url",
 	"us",
 	"v2",
+	"vv",
+	"vvv",
+	"vvvv",
 	"vpc",
 	"whitelist",
 	"yaml",
