@@ -2,6 +2,7 @@ package flink
 
 import (
 	"fmt"
+	"time"
 
 	"github.com/spf13/cobra"
 
@@ -9,11 +10,12 @@ import (
 )
 
 type statementOut struct {
-	Name         string `human:"Name" serialized:"name"`
-	Statement    string `human:"Statement" serialized:"statement"`
-	ComputePool  string `human:"Compute Pool" serialized:"compute_pool"`
-	Status       string `human:"Status" serialized:"status"`
-	StatusDetail string `human:"Status Detail,omitempty" serialized:"status_detail,omitempty"`
+	CreationDate time.Time `human:"Creation Date" serialized:"creation_date"`
+	Name         string    `human:"Name" serialized:"name"`
+	Statement    string    `human:"Statement" serialized:"statement"`
+	ComputePool  string    `human:"Compute Pool" serialized:"compute_pool"`
+	Status       string    `human:"Status" serialized:"status"`
+	StatusDetail string    `human:"Status Detail,omitempty" serialized:"status_detail,omitempty"`
 }
 
 func (c *command) newStatementCommand() *cobra.Command {
@@ -24,6 +26,8 @@ func (c *command) newStatementCommand() *cobra.Command {
 
 	cmd.AddCommand(c.newStatementDeleteCommand())
 	cmd.AddCommand(c.newStatementListCommand())
+	cmd.AddCommand(c.newStatementGetDetailsCommand())
+	cmd.AddCommand(c.newExceptionsCommand())
 
 	return cmd
 }
@@ -59,10 +63,11 @@ func (c *command) validStatementArgs(cmd *cobra.Command, args []string) []string
 		return nil
 	}
 
-	statements, err := client.ListStatements(environmentId, c.Context.LastOrgId)
+	listStatementsResponse, err := client.ListStatements(environmentId, c.Context.LastOrgId, "")
 	if err != nil {
 		return nil
 	}
+	statements := listStatementsResponse.GetData()
 
 	suggestions := make([]string, len(statements))
 	for i, statement := range statements {
