@@ -18,7 +18,7 @@ import (
 	"github.com/confluentinc/cli/internal/pkg/serdes"
 )
 
-func (c *command) newKafkaTopicProduceCommand() *cobra.Command {
+func (c *Command) newKafkaTopicProduceCommand() *cobra.Command {
 	cmd := &cobra.Command{
 		Use:   "produce <topic>",
 		Args:  cobra.ExactArgs(1),
@@ -43,7 +43,7 @@ func (c *command) newKafkaTopicProduceCommand() *cobra.Command {
 	return cmd
 }
 
-func (c *command) kafkaTopicProduce(cmd *cobra.Command, args []string) error {
+func (c *Command) kafkaTopicProduce(cmd *cobra.Command, args []string) error {
 	if c.Config.LocalPorts == nil {
 		return errors.NewErrorWithSuggestions(errors.FailedToReadPortsErrorMsg, errors.FailedToReadPortsSuggestions)
 	}
@@ -72,6 +72,7 @@ func (c *command) kafkaTopicProduce(cmd *cobra.Command, args []string) error {
 	}
 
 	output.ErrPrintln(errors.StartingProducerMsg)
+	output.ErrPrintln("Type a message and press ENTER to produce to the topic.")
 
 	var scanErr error
 	input, scan := kafka.PrepareInputChannel(&scanErr)
