@@ -128,26 +128,26 @@ func TestDynamicContext_ParseFlagsIntoContext(t *testing.T) {
 			ctx:         getEnvFlagContext(),
 		},
 	}
-	for _, tt := range tests {
+	for _, test := range tests {
 		cmd := &cobra.Command{Run: func(cmd *cobra.Command, args []string) {}}
 		cmd.Flags().String("environment", "", "Environment ID.")
 		cmd.Flags().String("cluster", "", "Kafka cluster ID.")
-		err := cmd.ParseFlags([]string{"--cluster", tt.cluster, "--environment", tt.environment})
+		err := cmd.ParseFlags([]string{"--cluster", test.cluster, "--environment", test.environment})
 		require.NoError(t, err)
-		initialEnvId := tt.ctx.GetCurrentEnvironment()
-		initialActiveKafkaId := tt.ctx.KafkaClusterContext.GetActiveKafkaClusterId()
-		err = tt.ctx.ParseFlagsIntoContext(cmd, client)
+		initialEnvId := test.ctx.GetCurrentEnvironment()
+		initialActiveKafkaId := test.ctx.KafkaClusterContext.GetActiveKafkaClusterId()
+		err = test.ctx.ParseFlagsIntoContext(cmd, client)
 		require.NoError(t, err)
-		finalEnv := tt.ctx.GetCurrentEnvironment()
-		finalCluster := tt.ctx.KafkaClusterContext.GetActiveKafkaClusterId()
-		if tt.environment != "" {
-			require.Equal(t, tt.environment, finalEnv)
+		finalEnv := test.ctx.GetCurrentEnvironment()
+		finalCluster := test.ctx.KafkaClusterContext.GetActiveKafkaClusterId()
+		if test.environment != "" {
+			require.Equal(t, test.environment, finalEnv)
 		} else {
 			require.Equal(t, initialEnvId, finalEnv)
 		}
-		if tt.cluster != "" {
-			require.Equal(t, tt.cluster, finalCluster)
-		} else if tt.environment == "" {
+		if test.cluster != "" {
+			require.Equal(t, test.cluster, finalCluster)
+		} else if test.environment == "" {
 			require.Equal(t, initialActiveKafkaId, finalCluster)
 		}
 	}
