@@ -18,15 +18,6 @@ import (
 	"github.com/confluentinc/cli/internal/pkg/output"
 )
 
-const MOCK_STATEMENTS_OUTPUT_DEMO = true
-
-type StoreInterface interface {
-	ProcessStatement(statement string) (*types.ProcessedStatement, *types.StatementError)
-	FetchStatementResults(types.ProcessedStatement) (*types.ProcessedStatement, *types.StatementError)
-	DeleteStatement(statementName string) bool
-	WaitPendingStatement(ctx context.Context, statement types.ProcessedStatement) (*types.ProcessedStatement, *types.StatementError)
-}
-
 type Store struct {
 	Properties       map[string]string
 	exitApplication  func()
@@ -252,13 +243,13 @@ func extractPageToken(nextUrl string) (string, error) {
 	return params.Get("page_token"), nil
 }
 
-func NewStore(client ccloudv2.GatewayClientInterface, exitApplication func(), appOptions *types.ApplicationOptions, authenticated func() error) StoreInterface {
+func NewStore(client ccloudv2.GatewayClientInterface, exitApplication func(), appOptions *types.ApplicationOptions, tokenRefreshFunc func() error) types.StoreInterface {
 	return &Store{
 		Properties:       appOptions.GetDefaultProperties(),
 		client:           client,
 		exitApplication:  exitApplication,
 		appOptions:       appOptions,
-		tokenRefreshFunc: authenticated,
+		tokenRefreshFunc: tokenRefreshFunc,
 	}
 }
 
