@@ -10,6 +10,7 @@ type ApplicationOptions struct {
 	KafkaClusterId    string
 	ComputePoolId     string
 	IdentityPoolId    string
+	Verbose           bool
 }
 
 func (a *ApplicationOptions) GetDefaultProperties() map[string]string {
@@ -74,3 +75,9 @@ func (a *ApplicationOptions) GetIdentityPoolId() string {
 	}
 	return ""
 }
+func (a *ApplicationOptions) GetVerbose() bool {
+	if a != nil {
+		return a.Verbose
+	}
+	return false
+}
