@@ -8,7 +8,6 @@ import (
 
 func AuthenticatedDynamicConfigMock() *dynamicconfig.DynamicConfig {
 	cfg := v1.AuthenticatedCloudConfigMock()
-	client := mock.NewClientMock()
 	v2Client := mock.NewV2ClientMock()
-	return dynamicconfig.New(cfg, client, v2Client)
+	return dynamicconfig.New(cfg, v2Client)
 }
