@@ -29,15 +29,15 @@ func (s *CLITestSuite) TestCluster() {
 		{args: "schema-registry cluster list", fixture: "cluster/list-type-schema-registry.golden"},
 	}
 
-	for _, tt := range tests {
-		tt.login = "onprem"
-		s.runIntegrationTest(tt)
+	for _, test := range tests {
+		test.login = "onprem"
+		s.runIntegrationTest(test)
 	}
 
 	_ = os.Setenv("XX_FLAG_CLUSTER_REGISTRY_ENABLE", "false")
 }
 
-func (s *CLITestSuite) TestClusterRegistry() {
+func (s *CLITestSuite) TestCluster_Registry() {
 	tests := []CLITest{
 		{args: "cluster register --cluster-name theMdsKSQLCluster --kafka-cluster kafka-GUID --ksql-cluster ksql-name --hosts 10.4.4.4:9004 --protocol PLAIN", fixture: "cluster/register-invalid-protocol.golden", exitCode: 1},
 		{args: "cluster register --cluster-name theMdsKSQLCluster --kafka-cluster kafka-GUID --ksql-cluster ksql-name --protocol SASL_PLAINTEXT", fixture: "cluster/register-missing-hosts.golden", exitCode: 1},
@@ -47,13 +47,13 @@ func (s *CLITestSuite) TestClusterRegistry() {
 		{args: "cluster unregister", fixture: "cluster/unregister-missing-name.golden", exitCode: 1},
 	}
 
-	for _, tt := range tests {
-		tt.login = "onprem"
-		s.runIntegrationTest(tt)
+	for _, test := range tests {
+		test.login = "onprem"
+		s.runIntegrationTest(test)
 	}
 }
 
-func (s *CLITestSuite) TestClusterScopedId() {
+func (s *CLITestSuite) TestClusterDescribe_ScopedId() {
 	// everything
 	cpIdURL1 := serveClusterScopedId(&cluster.ScopedId{
 		ID: "crn://md01.example.com/kafka=kafkaCluster1/connect=connectClusterA",
@@ -105,9 +105,9 @@ func (s *CLITestSuite) TestClusterScopedId() {
 		{args: fmt.Sprintf("cluster describe --url %s --ca-cert-path %s", cpIdURL3TLS, caCertPath), fixture: "cluster/scoped-id3.golden"},
 		{args: fmt.Sprintf("cluster describe --url %s", cpIdURL4), fixture: "cluster/scoped-id4.golden", exitCode: 1},
 	}
-	for _, tt := range tests {
-		tt.login = "onprem"
-		s.runIntegrationTest(tt)
+	for _, test := range tests {
+		test.login = "onprem"
+		s.runIntegrationTest(test)
 	}
 }
 
