@@ -12,6 +12,7 @@ var (
 	// TestCloudUrl is used to hardcode a specific port (1024) so tests can identify CCloud URLs
 	TestCloudUrl          = url.URL{Scheme: "http", Host: "127.0.0.1:1024"}
 	TestV2CloudUrl        = url.URL{Scheme: "http", Host: "127.0.0.1:2048"}
+	TestHubUrl            = url.URL{Scheme: "http", Host: "127.0.0.1:4096"}
 	TestKafkaRestProxyUrl = url.URL{Scheme: "http", Host: "127.0.0.1:1025"}
 	TestFlinkGatewayUrl   = url.URL{Scheme: "http", Host: "127.0.0.1:1026"}
 )
@@ -25,6 +26,7 @@ type TestBackend struct {
 	flinkGateway   *httptest.Server
 	mds            *httptest.Server
 	sr             *httptest.Server
+	hub            *httptest.Server
 }
 
 func StartTestBackend(t *testing.T, isAuditLogEnabled bool) *TestBackend {
@@ -38,6 +40,7 @@ func StartTestBackend(t *testing.T, isAuditLogEnabled bool) *TestBackend {
 		flinkGateway:   newTestCloudServer(NewFlinkGatewayRouter(t), TestFlinkGatewayUrl.Host),
 		mds:            httptest.NewServer(NewMdsRouter(t)),
 		sr:             httptest.NewServer(NewSRRouter(t)),
+		hub:            newTestCloudServer(NewHubRouter(t), TestHubUrl.Host),
 	}
 
 	cloudRouter.srApiUrl = backend.sr.URL
@@ -90,6 +93,9 @@ func (b *TestBackend) Close() {
 	if b.sr != nil {
 		b.sr.Close()
 	}
+	if b.hub != nil {
+		b.hub.Close()
+	}
 }
 
 func (b *TestBackend) GetCloudUrl() string {
